@@ -71,6 +71,8 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
     
     print('\nModel Metrics')
     format_dict = {'train':'{0:,.4}', 'test': '{0:.4}', 'deviation_pct': '{:.2%}'}
+
+    metricx.set_index('metric', inplace=True)
     display(metricx.style.format(format_dict))
     
     # Determine log-loss cutpoint
@@ -114,6 +116,7 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
         print('Classification Metrics')
         print(f'Using an F-Score of {f_score}')
         format_dict = {'train':'{0:,.4}', 'test': '{0:.4}', 'deviation_pct': '{:.2%}'}
+        classification_metricx.set_index('metric', inplace=True)
         display(classification_metricx.style.format(format_dict))
         
         print('Accuracy: % of Accurate Predictions. (True Positives + True Negatives) / Total Population')
@@ -245,5 +248,11 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
             
     print('\nLift/Gains Table')
     display(lift)
-     
-    return
\ No newline at end of file
+    
+    if classification == True:
+        return metricx, lift, classification_metricx
+    
+    else:
+        return metricx, lift
+    
+
